==> lnmp2.0.tar.gz: lnmp2.0/include/version.sh <==
#!/usr/bin/env bash

Autoconf_Ver='autoconf-2.13'
Libiconv_Ver='libiconv-1.17'
LibMcrypt_Ver='libmcrypt-2.5.8'
Mcypt_Ver='mcrypt-2.6.8'
Mhash_Ver='mhash-0.9.9.9'
Freetype_Ver='freetype-2.7'
Freetype_New_Ver='freetype-2.13.0'
Curl_Ver='curl-7.62.0'
Pcre_Ver='pcre-8.45'
Jemalloc_Ver='jemalloc-5.3.0'
TCMalloc_Ver='gperftools-2.9.1'
Libunwind_Ver='libunwind-1.2.1'
Libicu4c_Ver='icu4c-58_3'
Boost_Ver='boost_1_59_0'
Boost_New_Ver='boost_1_67_0'
Openssl_Ver='openssl-1.0.2u'
Openssl_New_Ver='openssl-1.1.1t'
Nghttp2_Ver='nghttp2-1.52.0'
Libzip_Ver='libzip-1.3.2'
Luajit_Ver='luajit2-2.1-20230119'
LuaNginxModule='lua-nginx-module-0.10.24'
LuaRestyCore='lua-resty-core-0.1.26'
LuaRestyLrucache='lua-resty-lrucache-0.13'
NgxDevelKit='ngx_devel_kit-0.3.2'
Nginx_Ver='nginx-1.24.0'
NgxFancyIndex_Ver='ngx-fancyindex-0.5.2'
if [ "${DBSelect}" = "1" ]; then
    Mysql_Ver='mysql-5.1.73'
elif [ "${DBSelect}" = "2" ]; then
    Mysql_Ver='mysql-5.5.62'
elif [ "${DBSelect}" = "3" ]; then
    Mysql_Ver='mysql-5.6.51'
elif [ "${DBSelect}" = "4" ]; then
    Mysql_Ver='mysql-5.7.42'
elif [ "${DBSelect}" = "5" ]; then
    Mysql_Ver='mysql-8.0.33'
elif [ "${DBSelect}" = "6" ]; then
    Mariadb_Ver='mariadb-5.5.68'
elif [ "${DBSelect}" = "7" ]; then
    Mariadb_Ver='mariadb-10.4.29'
elif [ "${DBSelect}" = "8" ]; then
    Mariadb_Ver='mariadb-10.5.20'
elif [ "${DBSelect}" = "9" ]; then
    Mariadb_Ver='mariadb-10.6.13'
elif [ "${DBSelect}" = "10" ]; then
    Mariadb_Ver='mariadb-10.11.3'
fi
if [ "${PHPSelect}" = "1" ]; then
    Php_Ver='php-5.2.17'
elif [ "${PHPSelect}" = "2" ]; then
    Php_Ver='php-5.3.29'
elif [ "${PHPSelect}" = "3" ]; then
    Php_Ver='php-5.4.45'
elif [ "${PHPSelect}" = "4" ]; then
    Php_Ver='php-5.5.38'
elif [ "${PHPSelect}" = "5" ]; then
    Php_Ver='php-5.6.40'
elif [ "${PHPSelect}" = "6" ]; then
    Php_Ver='php-7.0.33'
elif [ "${PHPSelect}" = "7" ]; then
    Php_Ver='php-7.1.33'
elif [ "${PHPSelect}" = "8" ]; then
    Php_Ver='php-7.2.34'
elif [ "${PHPSelect}" = "9" ]; then
    Php_Ver='php-7.3.33'
elif [ "${PHPSelect}" = "10" ]; then
    Php_Ver='php-7.4.33'
elif [ "${PHPSelect}" = "11" ]; then
    Php_Ver='php-8.0.28'
elif [ "${PHPSelect}" = "12" ]; then
    Php_Ver='php-8.1.19'
elif [ "${PHPSelect}" = "13" ]; then
    Php_Ver='php-8.2.6'
fi
if [[ "${PHPSelect}" =~ ^[123]$ ]]; then
    PhpMyAdmin_Ver='phpMyAdmin-4.0.10.20-all-languages'
elif [[ "${PHPSelect}" =~ ^[456]$ ]]; then
    PhpMyAdmin_Ver='phpMyAdmin-4.9.11-all-languages'
else
    PhpMyAdmin_Ver='phpMyAdmin-5.2.1-all-languages'
fi
APR_Ver='apr-1.7.4'
APR_Util_Ver='apr-util-1.6.3'
if [ "${ApacheSelect}" = "1" ]; then
    Apache_Ver='httpd-2.2.34'
elif [ "${ApacheSelect}" = "2" ]; then
    Apache_Ver='httpd-2.4.57'
fi

Pureftpd_Ver='pure-ftpd-1.0.49'

XCache_Ver='xcache-3.2.0'
ImageMagick_Ver='ImageMagick-7.1.1-8'
Imagick_Ver='imagick-3.7.0'
ZendOpcache_Ver='zendopcache-7.0.5'
Redis_Stable_Ver='redis-7.0.11'
PHPRedis_Ver='redis-5.3.7'
Memcached_Ver='memcached-1.6.15'
Libmemcached_Ver='libmemcached-1.0.18'
PHPMemcached_Ver='memcached-2.2.0'
PHP7Memcached_Ver='memcached-3.1.5'
PHP8Memcached_Ver='memcached-3.2.0'
PHPMemcache_Ver='memcache-3.0.8'
PHP7Memcache_Ver='memcache-4.0.5.2'
PHP8Memcache_Ver='memcache-8.2'
PHPOldApcu_Ver='apcu-4.0.11'
PHPNewApcu_Ver='apcu-5.1.22'
PHPApcu_Bc_Ver='apcu_bc-1.0.5'
PHPSodium_Ver='libsodium-2.0.23'
PHPSwoole_Ver='swoole-5.0.3'

==> lnmp2.1.tar.gz: lnmp2.1/include/version.sh <==
#!/usr/bin/env bash

Autoconf_Ver='autoconf-2.13'
Libiconv_Ver='libiconv-1.17'
LibMcrypt_Ver='libmcrypt-2.5.8'
Mcypt_Ver='mcrypt-2.6.8'
Mhash_Ver='mhash-0.9.9.9'
Freetype_Ver='freetype-2.7'
Freetype_New_Ver='freetype-2.13.0'
Curl_Ver='curl-7.62.0'
Pcre_Ver='pcre-8.45'
Jemalloc_Ver='jemalloc-5.3.0'
TCMalloc_Ver='gperftools-2.9.1'
Libunwind_Ver='libunwind-1.2.1'
Libicu4c_Ver='icu4c-58_3'
Boost_Ver='boost_1_59_0'
Boost_New_Ver='boost_1_67_0'
Openssl_Ver='openssl-1.0.2u'
Openssl_New_Ver='openssl-1.1.1w'
Nghttp2_Ver='nghttp2-1.52.0'
Libzip_Ver='libzip-1.3.2'
Luajit_Ver='luajit2-2.1-20230119'
LuaNginxModule='lua-nginx-module-0.10.26'
LuaRestyCore='lua-resty-core-0.1.28'
LuaRestyLrucache='lua-resty-lrucache-0.13'
NgxDevelKit='ngx_devel_kit-0.3.3'
Nginx_Ver='nginx-1.26.0'
NgxFancyIndex_Ver='ngx-fancyindex-0.5.2'
if [ "${DBSelect}" = "1" ]; then
    Mysql_Ver='mysql-5.1.73'
elif [ "${DBSelect}" = "2" ]; then
    Mysql_Ver='mysql-5.5.62'
elif [ "${DBSelect}" = "3" ]; then
    Mysql_Ver='mysql-5.6.51'
elif [ "${DBSelect}" = "4" ]; then
    Mysql_Ver='mysql-5.7.44'
elif [ "${DBSelect}" = "5" ]; then
    Mysql_Ver='mysql-8.0.37'
elif [ "${DBSelect}" = "6" ]; then
    Mariadb_Ver='mariadb-5.5.68'
elif [ "${DBSelect}" = "7" ]; then
    Mariadb_Ver='mariadb-10.4.33'
elif [ "${DBSelect}" = "8" ]; then
    Mariadb_Ver='mariadb-10.5.24'
elif [ "${DBSelect}" = "9" ]; then
    Mariadb_Ver='mariadb-10.6.17'
elif [ "${DBSelect}" = "10" ]; then
    Mariadb_Ver='mariadb-10.11.7'
elif [ "${DBSelect}" = "11" ]; then
    Mysql_Ver='mysql-8.4.0'
fi
if [ "${PHPSelect}" = "1" ]; then
    Php_Ver='php-5.2.17'
elif [ "${PHPSelect}" = "2" ]; then
    Php_Ver='php-5.3.29'
elif [ "${PHPSelect}" = "3" ]; then
    Php_Ver='php-5.4.45'
elif [ "${PHPSelect}" = "4" ]; then
    Php_Ver='php-5.5.38'
elif [ "${PHPSelect}" = "5" ]; then
    Php_Ver='php-5.6.40'
elif [ "${PHPSelect}" = "6" ]; then
    Php_Ver='php-7.0.33'
elif [ "${PHPSelect}" = "7" ]; then
    Php_Ver='php-7.1.33'
elif [ "${PHPSelect}" = "8" ]; then
    Php_Ver='php-7.2.34'
elif [ "${PHPSelect}" = "9" ]; then
    Php_Ver='php-7.3.33'
elif [ "${PHPSelect}" = "10" ]; then
    Php_Ver='php-7.4.33'
elif [ "${PHPSelect}" = "11" ]; then
    Php_Ver='php-8.0.30'
elif [ "${PHPSelect}" = "12" ]; then
    Php_Ver='php-8.1.28'
elif [ "${PHPSelect}" = "13" ]; then
    Php_Ver='php-8.2.19'
elif [ "${PHPSelect}" = "14" ]; then
    Php_Ver='php-8.3.7'
fi
if [[ "${PHPSelect}" =~ ^[123]$ ]]; then
    PhpMyAdmin_Ver='phpMyAdmin-4.0.10.20-all-languages'
elif [[ "${PHPSelect}" =~ ^[456]$ ]]; then
    PhpMyAdmin_Ver='phpMyAdmin-4.9.11-all-languages'
else
    PhpMyAdmin_Ver='phpMyAdmin-5.2.1-all-languages'
fi
APR_Ver='apr-1.7.4'
APR_Util_Ver='apr-util-1.6.3'
if [ "${ApacheSelect}" = "1" ]; then
    Apache_Ver='httpd-2.2.34'
elif [ "${ApacheSelect}" = "2" ]; then
    Apache_Ver='httpd-2.4.57'
fi

Pureftpd_Ver='pure-ftpd-1.0.49'

XCache_Ver='xcache-3.2.0'
ImageMagick_Ver='ImageMagick-7.1.1-8'
Imagick_Ver='imagick-3.7.0'
ZendOpcache_Ver='zendopcache-7.0.5'
Redis_Stable_Ver='redis-7.0.11'
PHPRedis_Ver='redis-5.3.7'
Memcached_Ver='memcached-1.6.15'
Libmemcached_Ver='libmemcached-1.0.18'
PHPMemcached_Ver='memcached-2.2.0'
PHP7Memcached_Ver='memcached-3.1.5'
PHP8Memcached_Ver='memcached-3.2.0'
PHPMemcache_Ver='memcache-3.0.8'
PHP7Memcache_Ver='memcache-4.0.5.2'
PHP8Memcache_Ver='memcache-8.2'
PHPOldApcu_Ver='apcu-4.0.11'
PHPNewApcu_Ver='apcu-5.1.22'
PHPApcu_Bc_Ver='apcu_bc-1.0.5'
PHPSodium_Ver='libsodium-2.0.23'
PHPSwoole_Ver='swoole-5.1.1'
